#[derive(CliCommand)]
{
// Attributes available to this derive:
#[cli]
}
Derive typed subcommand dispatch for an enum.
See the cli-ui crate documentation for full usage and attribute reference.
#[derive(CliCommand)]
{
// Attributes available to this derive:
#[cli]
}
Derive typed subcommand dispatch for an enum.
See the cli-ui crate documentation for full usage and attribute reference.