#[derive(CliOptions)]
{
// Attributes available to this derive:
#[cli]
#[arg]
}
Derive typed argument parsing for a struct.
See the cli-ui crate documentation for full usage and attribute reference.
#[derive(CliOptions)]
{
// Attributes available to this derive:
#[cli]
#[arg]
}
Derive typed argument parsing for a struct.
See the cli-ui crate documentation for full usage and attribute reference.