Module log

Module log 

Framed log messages — ports @clack/prompts log.{info,warn,error,success,step,message}.

Each call prints to stderr, prefixed with (a connector bar) so consecutive log.* calls render as a single connected column matching clack’s frame style.

Functions

error
Cancel palette — error.
info
Accent — neutral info.
message
Print message with symbol as the first column for the first line, and for any additional lines. Adds one blank connector line above.
step
Success — single step completed (between prompts).
success
Success — successful completion.
warn
Error palette — warning.
warning
Alias for warn.