message

Function message 

pub fn message(msg: impl AsRef<str>, symbol: &str)
Print message with symbol as the first column for the first line, and for any additional lines. Adds one blank connector line above.