Module multiselect

Module multiselect 

Multi-choice select prompt — built on the Prompt trait.

Structs

MultiSelectPrompt
Builder returned by multiselect().
MultiSelected
Set of options the user checked off, returned by multiselect.

Functions

multiselect
Ask the user to check any number of options from a list. Space toggles, Enter submits.