Module text

Module text 

Free-text and masked password prompts — built on the Prompt trait.

Structs

SecretPrompt
Builder returned by secret().
TextPrompt
Builder returned by text(). Configure with the chainable methods, then call run to read a line from the user.

Functions

secret
Ask the user for a masked line of text (passwords, API keys).
text
Ask the user for one line of text.